| Title: | Utility Functions of Fangzhou Xie |
|---|---|
| Description: | This is a collection of some useful functions when dealing with text data. Currently it only contains a very efficient function of decoding HTML entities in character vectors by 'Rcpp' routine. |
| Authors: | Fangzhou Xie [aut, cre] (ORCID: <https://orcid.org/0000-0001-7702-093X>) |
| Maintainer: | Fangzhou Xie <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.2 |
| Built: | 2026-06-04 08:21:52 UTC |
| Source: | https://github.com/fangzhou-xie/xutils |
This function is a wrapper around existing C++ code on decoding HTML entities. The original C++ code is given by Christoph. Please refer to the answer on SO here.
html_decode(str)html_decode(str)
str |
A character vector |
Decoded character vector
html_decode(c("&", "€"))html_decode(c("&", "€"))